@@ -11,6 +11,7 @@
 #include "editor/widgets/preferredlineeditwidget.h"
 #include "phonecomboboxtype.h"
 
+#include <KLineEditEventHandler>
 #include <KLocalizedString>
 
 #include <QHBoxLayout>
@@ -28,7 +29,7 @@ PhoneWidget::PhoneWidget(QWidget *parent)
     layout->setSpacing(0);
     layout->setContentsMargins({});
 
-    mPhoneNumberEdit->setTrapReturnKey(true);
+    KLineEditEventHandler::catchReturnKey(mPhoneNumberEdit);
     mPhoneNumberEdit->setPlaceholderText(i18nc("@info:placeholder", "Add a Phone Number"));
     mPhoneNumberEdit->setObjectName(QLatin1StringView("phonenumber"));
     layout->addWidget(mPhoneNumberEdit);
@@ -52,9 +53,10 @@ PhoneWidget::PhoneWidget(QWidget *parent)
 
 PhoneWidget::~PhoneWidget() = default;
 
-void PhoneWidget::updateAddRemoveButton(bool addButtonEnabled)
+void PhoneWidget::updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled)
 {
     mAddButton->setEnabled(addButtonEnabled);
+    mRemoveButton->setEnabled(removeButtonEnabled);
 }
 
 KContacts::PhoneNumber PhoneWidget::storePhone()
